package oliot.aika.olio;

/**
 * Ensimmäinen kunnon olioesimerkki
 * @author  Vesa Lappalainen @version 1.0, 01.02.2003
 * @author Santtu Viitanen @version 1.1, 7.7.2011
 * @example
 * <pre name="test">
 *  Aika a1 = new Aika(12,15);
 *  a1.lisaa(55);    a1.toString() === "13:10";
 * </pre>
 */
public class Aika implements AikaRajapinta {  // luokka
    
    private int h;  // attribuuti
    private int m;

    
    /**
     * alustetaan keskiyöhön
     */
    public Aika() {
        this.h = 0;
        this.m = 0;
    }
     
    
    
    /**
     * Alustaa ajan
     * @param h tunnit
     * @param m minuutit
     * @example
     * <pre name="test">
     * new Aika(12,15).toString() === "12:15";
     * </pre>
     */
    public Aika(int h, int m) { // Muodostaja
        this.h = h;
        this.m = m;
    }

    
    
    /**
     * Lisää aikaan valitun minuuttimäärän
     * @param lisaMin lisättävä minuuttimäärä
     * @example
     * <pre name="test">
     *  Aika a1 = new Aika(13,16);
     *  a1.lisaa(27);    a1.toString() === "13:43";
     *  a1.lisaa(39);    a1.toString() === "14:22";
     * </pre>
     */
    @Override
    public void lisaa(int lisaMin) {
        int yht_min = this.h * 60 + this.m + lisaMin;
        this.h = yht_min / 60;
        this.m = yht_min % 60;
    }    
    
    
    /**
     * @return aika merkkijonona muodossa 12:05
     * @example
     * <pre name="test">
     * new Aika(7,5).toString() === "07:05";
     * new Aika(12,15).toString() === "12:15";
     * </pre>
     */
    @Override
    public String toString() {
        return String.format("%02d:%02d", this.h, this.m);
    }
    
    /*
    @Override
    public boolean equals(Object o) {
        if (!(o instanceof AikaRajapinta))
            return false;
        AikaRajapinta a = (AikaRajapinta) o;
        return h == a.h && m == a.m;
    }
    */



    @Override
    public int hashCode() {
        // TODO Auto-generated method stub
        return this.h * 3600 + this.m * 60;
    }

    
}
